class ServerCreateOptions(object):
    """ServerCreateOptions.

    :param name: A name used to identify the server.
    :type name: str
    """

    def __init__(self, name=None):
        self.name = name

    def to_json(self):
        return {
            'name': self.name
        }
